EventInfo

Enum EventInfo 

pub enum EventInfo {
Show 36 variants WifiReady, ScanDone { status: u32, number: u8, scan_id: u8, }, StationStart, StationStop, StationConnected { ssid: Ssid, bssid: [u8; 6], channel: u8, authmode: u32, aid: u16, }, StationDisconnected { ssid: Ssid, bssid: [u8; 6], reason: u16, rssi: i8, }, StationAuthenticationModeChange { old_mode: u32, new_mode: u32, }, StationWifiProtectedStatusEnrolleeSuccess { credentials: Collection<CredentialsInfo>, }, StationWifiProtectedStatusEnrolleeFailed, StationWifiProtectedStatusEnrolleeTimeout, StationWifiProtectedStatusEnrolleePin { pin_code: [u8; 8], }, StationWifiProtectedStatusEnrolleePushButtonConfigurationOverlap, AccessPointStart, AccessPointStop, AccessPointStationConnected { mac: [u8; 6], aid: u16, is_mesh_child: bool, }, AccessPointStationDisconnected { mac: [u8; 6], aid: u8, is_mesh_child: bool, reason: u16, }, AccessPointProbeRequestReceived { rssi: i8, mac: [u8; 6], }, FineTimingMeasurementReport { peer_mac: [u8; 6], status: u32, rtt_raw: u32, rtt_est: u32, dist_est: u32, entries: Collection<FineTimingMeasurementReportInfo>, }, StationBasicServiceSetReceivedSignalStrengthIndicatorLow { rssi: i8, }, ActionTransmissionStatus { ifx: u32, context: u32, status: u32, op_id: u8, channel: u8, }, RemainOnChannelDone { context: u32, status: u32, op_id: u8, channel: u8, }, StationBeaconTimeout, ConnectionlessModuleWakeIntervalStart, AccessPointWifiProtectedStatusRegistrarSuccess { peer_macaddr: [u8; 6], }, AccessPointWifiProtectedStatusRegistrarFailed { reason: u32, peer_macaddr: [u8; 6], }, AccessPointWifiProtectedStatusRegistrarTimeout, AccessPointWifiProtectedStatusRegistrarPin { pin_code: [u8; 8], }, AccessPointWifiProtectedStatusRegistrarPushButtonConfigurationOverlap, IndividualTargetWakeTimeSetup, IndividualTargetWakeTimeTeardown, IndividualTargetWakeTimeProbe, IndividualTargetWakeTimeSuspend, TargetWakeTimeWakeup, BroadcastTargetWakeTimeSetup, BroadcastTargetWakeTimeTeardown, HomeChannelChange,
}
Available on crate feature unstable only.
Event including the payload.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



WifiReady

Wi-Fi is ready for operation.



ScanDone

Scan operation has completed.

Fields

status: u32

Status of scanning APs: 0 — success, 1 - failure

number: u8

Number of scan results

scan_id: u8

Scan sequence number, used for block scan



StationStart

Station mode started.



StationStop

Station mode stopped.



StationConnected

Station connected to a network.

Fields

ssid: Ssid

SSID of connected AP

bssid: [u8; 6]

BSSID of connected AP

channel: u8

Channel of connected AP

authmode: u32

Authentication mode used by the connection

aid: u16

Authentication id assigned by the connected AP



StationDisconnected

Station disconnected from a network.

Fields

ssid: Ssid

SSID of disconnected AP

bssid: [u8; 6]

BSSID of disconnected AP

reason: u16

Disconnection reason

rssi: i8

Disconnection RSSI



StationAuthenticationModeChange

Station authentication mode changed.

Fields

old_mode: u32

Old auth mode of AP

new_mode: u32

New auth mode of AP



StationWifiProtectedStatusEnrolleeSuccess

Station Wi-Fi-Protected-Status succeeds in enrollee mode.

Fields

credentials: Collection<CredentialsInfo>

Credentials



StationWifiProtectedStatusEnrolleeFailed

Station Wi-Fi-Protected-Status fails in enrollee mode.



StationWifiProtectedStatusEnrolleeTimeout

Station Wi-Fi-Protected-Status timeout in enrollee mode.



StationWifiProtectedStatusEnrolleePin

Station Wi-Fi-Protected-Status pin code in enrollee mode.

Fields

pin_code: [u8; 8]

PIN code of station in enrollee mode



StationWifiProtectedStatusEnrolleePushButtonConfigurationOverlap

Station Wi-Fi-Protected-Status overlap in enrollee mode.



AccessPointStart

Soft-AccessPoint start.



AccessPointStop

Soft-AccessPoint stop.



AccessPointStationConnected

A station connected to Soft-AccessPoint.

Fields

mac: [u8; 6]

MAC address of the station connected to Soft-AP

aid: u16

AID assigned by the Soft-AP to the connected station

is_mesh_child: bool

Flag indicating whether the connected station is a mesh child



AccessPointStationDisconnected

A station disconnected from Soft-AccessPoint.

Fields

mac: [u8; 6]

MAC address of the station disconnects from the soft-AP

aid: u8

AID that the Soft-AP assigned to the disconnected station

is_mesh_child: bool

Flag indicating whether the disconnected station is a mesh child

reason: u16

Disconnection reason



AccessPointProbeRequestReceived

Received probe request packet in Soft-AccessPoint interface.

Fields

rssi: i8

Received probe request signal strength

mac: [u8; 6]

MAC address of the station which send probe request



FineTimingMeasurementReport

Received report of Fine-Timing-Measurement procedure.

Fields

peer_mac: [u8; 6]

MAC address of the FTM Peer

status: u32

Status of the FTM operation

rtt_raw: u32

Raw average Round-Trip-Time with peer in Nano-Seconds

rtt_est: u32

Estimated Round-Trip-Time with peer in Nano-Seconds

dist_est: u32

Estimated one-way distance in Centi-Meters

entries: Collection<FineTimingMeasurementReportInfo>

Detailed FTM report entries.



StationBasicServiceSetReceivedSignalStrengthIndicatorLow

Station Receive-Signal-Strenght-Indicator goes below the configured threshold.

Fields

rssi: i8

RSSI value of bss



ActionTransmissionStatus

Status indication of Action Transmission operation.

Fields

ifx: u32

WiFi interface to send request to

context: u32

Context to identify the request

status: u32

Status of the operation

op_id: u8

ID of the corresponding operation that was provided during action tx request

channel: u8

Channel provided in tx request



RemainOnChannelDone

Remain-on-Channel operation complete.

Fields

context: u32

Context to identify the initiator of the request

status: u32

ROC status

op_id: u8

ID of the corresponding ROC operation

channel: u8

Channel provided in tx request



StationBeaconTimeout

Station beacon timeout.



ConnectionlessModuleWakeIntervalStart

Connectionless module wake interval has started.



AccessPointWifiProtectedStatusRegistrarSuccess

Soft-AccessPoint Wi-Fi-Protected-Status succeeded in registrar mode.

Fields

peer_macaddr: [u8; 6]

Enrollee mac address



AccessPointWifiProtectedStatusRegistrarFailed

Soft-AccessPoint Wi-Fi-Protected-Status failed in registrar mode.

Fields

reason: u32

WPS failure reason wps_fail_reason_t

peer_macaddr: [u8; 6]

Enrollee mac address



AccessPointWifiProtectedStatusRegistrarTimeout

Soft-AccessPoint Wi-Fi-Protected-Status timed out in registrar mode.



AccessPointWifiProtectedStatusRegistrarPin

Soft-AccessPoint Wi-Fi-Protected-Status pin code in registrar mode.

Fields

pin_code: [u8; 8]

PIN code of station in enrollee mode



AccessPointWifiProtectedStatusRegistrarPushButtonConfigurationOverlap

Soft-AccessPoint Wi-Fi-Protected-Status overlap in registrar mode.



IndividualTargetWakeTimeSetup

Individual Target-Wake-Time setup.



IndividualTargetWakeTimeTeardown

Individual Target-Wake-Time teardown.



IndividualTargetWakeTimeProbe

Individual Target-Wake-Time probe.



IndividualTargetWakeTimeSuspend

Individual Target-Wake-Time suspended.



TargetWakeTimeWakeup

Target-Wake-Wakeup event.



BroadcastTargetWakeTimeSetup

Broadcast-Target-Wake-Time setup.



BroadcastTargetWakeTimeTeardown

Broadcast-Target-Wake-Time teardown.



HomeChannelChange

Wi-Fi home channel change, doesn’t occur when scanning.