MessageResult

Enum MessageResult 

pub enum MessageResult {
    Lagged(u64),
    Message(EventInfo),
}
Available on crate feature unstable only.
Result for [EventSubscriber::next_message].

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Lagged(u64)

The subscriber did not receive all messages and lagged by the given amount of messages. (This is the amount of messages that were missed)



Message(EventInfo)

The received event.