disable_wifi_events

Function disable_wifi_events 

pub fn disable_wifi_events(events: EnumSet<WifiEvent>)
Available on crate feature unstable only.
Disable the given events.

Attention

Disabling events which are used internally will cause problems.

Therefore you usually don’t want to disable these:

crate::wifi::new always enables these events, even if they were disabled beforehand.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.