enable_wifi_events

Function enable_wifi_events 

pub fn enable_wifi_events(events: EnumSet<WifiEvent>)
Available on crate feature unstable only.
Enable the given events.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.