AccessPointCredential

Struct AccessPointCredential 

pub struct AccessPointCredential<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl AccessPointCredential<'_>

pub fn ssid(&self) -> &[u8]

Get the SSID of an access point.

pub fn passphrase(&self) -> &[u8]

Get passphrase for the access point.