AccessPointProbeRequestReceived

Struct AccessPointProbeRequestReceived 

pub struct AccessPointProbeRequestReceived<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl AccessPointProbeRequestReceived<'_>

pub fn rssi(&self) -> i32

Get received probe request SSID.

pub fn mac(&self) -> &[u8]

Get the MAC address of the station which send probe request.