AccessPointStationDisconnected

Struct AccessPointStationDisconnected 

pub struct AccessPointStationDisconnected<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl AccessPointStationDisconnected<'_>

pub fn mac(&self) -> &[u8]

Get the MAC address of the disconnected station.

pub fn reason(&self) -> u16

Get the reason for the disconnection.

pub fn aid(&self) -> u8

AID that the Soft-AccessPoint assigned to the disconnected station.

pub fn is_mesh_child(&self) -> bool

Flag indicating whether the connected station is a mesh child.