ActionTransmissionStatus

Struct ActionTransmissionStatus 

pub struct ActionTransmissionStatus<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl ActionTransmissionStatus<'_>

pub fn ifx(&self) -> u32

Get Wi-Fi interface to send request to.

pub fn context(&self) -> u32

Get context to identify the request.

pub fn op_id(&self) -> u8

ID of the corresponding operation that was provided during action tx request.

pub fn channel(&self) -> u8

Channel provided in tx request.

pub fn status(&self) -> u32

Get the status of the operation.