CredentialsInfo

Struct CredentialsInfo 

pub struct CredentialsInfo {
    pub ssid: Ssid,
    pub passphrase: [u8; 64],
}
Available on crate feature unstable only.
Credential info record.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

ssid: Ssid

SSID of AP

passphrase: [u8; 64]

Passphrase for the AP