EventSubscriber

Struct EventSubscriber 

pub struct EventSubscriber<'a> { /* private fields */ }
Available on crate feature unstable only.
Event subscriber.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl<'a> EventSubscriber<'a>

pub async fn next_event(&mut self) -> MessageResult

Wait for a published event

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub async fn next_event_pure(&mut self) -> EventInfo

Wait for a published event (ignoring lag results)

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.