FineTimingMeasurementReport

Struct FineTimingMeasurementReport 

pub struct FineTimingMeasurementReport<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl FineTimingMeasurementReport<'_>

pub fn peer_mac(&self) -> &[u8]

Get the MAC address of the FTM peer.

pub fn status(&self) -> u32

Get the status of the FTM operation.

pub fn rtt_raw(&self) -> u32

Get the raw round-trip time (RTT) in nanoseconds.

pub fn rtt_est(&self) -> u32

Get the estimated round-trip time (RTT) in nanoseconds.

pub fn dist_est(&self) -> u32

Get the distance estimate in centimeters.

pub fn report_num_entries(&self) -> u8

Get the number of entries in the FTM report data.

pub fn entries( &self, ) -> impl Iterator<Item = FineTimingMeasurementReportEntry<'_>> + '_

Returns an iterator over the detailed FTM report entries.