FineTimingMeasurementReportEntry

Struct FineTimingMeasurementReportEntry 

pub struct FineTimingMeasurementReportEntry<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl FineTimingMeasurementReportEntry<'_>

pub fn dialog_token(&self) -> u8

Gets the Dialog Token of the FTM frame.

pub fn rssi(&self) -> i8

Gets the Received Signal Strength Indicator (RSSI) of the FTM frame.

pub fn rtt(&self) -> u32

Gets the Round Trip Time (RTT) in picoseconds.

pub fn t1(&self) -> u64

Gets T1: Time of departure of the FTM frame from the Responder (in picoseconds).

pub fn t2(&self) -> u64

Gets T2: Time of arrival of the FTM frame at the Initiator (in picoseconds).

pub fn t3(&self) -> u64

Gets T3: Time of departure of the ACK from the Initiator (in picoseconds).

pub fn t4(&self) -> u64

Gets T4: Time of arrival of the ACK at the Responder (in picoseconds).