pub struct FineTimingMeasurementReportInfo {
pub dlog_token: u8,
pub rssi: i8,
pub rtt: u32,
pub t1: u64,
pub t2: u64,
pub t3: u64,
pub t4: u64,
}Available on crate feature
unstable only.Expand description
Detailed FTM report entry.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
dlog_token: u8Dialog Token of the FTM frame
rssi: i8RSSI of the FTM frame received
rtt: u32Round Trip Time in pSec with a peer
t1: u64Time of departure of FTM frame from FTM Responder in pSec
t2: u64Time of arrival of FTM frame at FTM Initiator in pSec
t3: u64Time of departure of ACK from FTM Initiator in pSec
t4: u64Time of arrival of ACK at FTM Responder in pSec