HomeChannelChange

Struct HomeChannelChange 

pub struct HomeChannelChange<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl HomeChannelChange<'_>

pub fn old_chan(&self) -> u8

Get the old home channel of the device.

pub fn old_snd(&self) -> u32

Get the old second channel of the device.

pub fn new_chan(&self) -> u8

Get the new home channel of the device.

pub fn new_snd(&self) -> u32

Get the new second channel of the device.