NeighborDiscoveryProtocolConfirmation

Struct NeighborDiscoveryProtocolConfirmation 

pub struct NeighborDiscoveryProtocolConfirmation<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl NeighborDiscoveryProtocolConfirmation<'_>

pub fn status(&self) -> u8

Get NDP status code.

pub fn id(&self) -> u8

Get NDP instance ID.

pub fn peer_nmi(&self) -> &[u8; 6]

Get Peer’s NAN Management Interface MAC.

pub fn peer_ndi(&self) -> &[u8; 6]

Get Peer’s NAN Data Interface MAC.

pub fn own_ndi(&self) -> &[u8; 6]

Get Own NAN Data Interface MAC.

pub fn svc_info(&self) -> &[u8; 64]

Get Service Specific Info.