NeighborDiscoveryProtocolIndication

Struct NeighborDiscoveryProtocolIndication 

pub struct NeighborDiscoveryProtocolIndication<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl NeighborDiscoveryProtocolIndication<'_>

pub fn publish_id(&self) -> u8

Get Publish ID for NAN Service.

pub fn ndp_id(&self) -> u8

Get NDF instance ID.

pub fn peer_nmi(&self) -> &[u8; 6]

Get Peer’s NAN Interface MAC.

pub fn peer_ndi(&self) -> &[u8; 6]

Get Peer’s NAN Data Interface MAC.

pub fn svc_info(&self) -> &[u8; 64]

Get Service Specific Info.