NeighborDiscoveryProtocolTerminated

Struct NeighborDiscoveryProtocolTerminated 

pub struct NeighborDiscoveryProtocolTerminated<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl NeighborDiscoveryProtocolTerminated<'_>

pub fn reason(&self) -> u8

Get termination reason code.

pub fn id(&self) -> u8

Get NDP instance ID.

pub fn init_ndi(&self) -> &[u8; 6]

Get Initiator’s NAN Data Interface MAC