ScanDone

Struct ScanDone 

pub struct ScanDone<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl ScanDone<'_>

pub fn status(&self) -> u32

Get the status of the scan operation.

pub fn number(&self) -> u8

Get the number of found APs.

pub fn id(&self) -> u8

Get the scan ID associated with this scan operation.