StationAuthenticationModeChange

Struct StationAuthenticationModeChange 

pub struct StationAuthenticationModeChange<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl StationAuthenticationModeChange<'_>

pub fn old_mode(&self) -> u32

Get the old authentication mode.

pub fn new_mode(&self) -> u32

Get the new authentication mode.