StationConnected

Struct StationConnected 

pub struct StationConnected<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl StationConnected<'_>

pub fn ssid(&self) -> &[u8]

Get the SSID of the connected station.

pub fn ssid_len(&self) -> u8

Get the length of the SSID.

pub fn bssid(&self) -> &[u8]

Get the BSSID (MAC address) of the connected station.

pub fn channel(&self) -> u8

Get the channel on which the station is connected.

pub fn authmode(&self) -> u32

Get the authentication mode used for the connection.

pub fn aid(&self) -> u16

Get the AID (Association Identifier) of the connected station.