StationDisconnected

Struct StationDisconnected 

pub struct StationDisconnected<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl StationDisconnected<'_>

pub fn ssid(&self) -> &[u8]

Get the SSID of the disconnected station.

pub fn ssid_len(&self) -> u8

Get the length of the SSID.

pub fn bssid(&self) -> &[u8]

Get the BSSID (MAC address) of the disconnected station.

pub fn reason(&self) -> u8

Get the reason for the disconnection.

pub fn rssi(&self) -> i8

Get the authentication mode used for the disconnection.