StationNeighborRep

Struct StationNeighborRep 

pub struct StationNeighborRep<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl StationNeighborRep<'_>

pub fn report(&self) -> &[u8]

Get the Neighbor Report received from the access point.

pub fn report_len(&self) -> u16

Get the length of report.