StationWifiProtectedStatusEnrolleeSuccess

Struct StationWifiProtectedStatusEnrolleeSuccess 

pub struct StationWifiProtectedStatusEnrolleeSuccess<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl StationWifiProtectedStatusEnrolleeSuccess<'_>

pub fn access_point_cred_cnt(&self) -> u8

Get number of access point credentials received.

pub fn access_point_cred(&self) -> &[AccessPointCredential<'_>]

Get all access point credentials received.