pub fn disable_wifi_events(events: EnumSet<WifiEvent>)Available on crate feature
unstable only.Expand description
Disable the given events.
Attention
Disabling events which are used internally will cause problems.
Therefore you usually don’t want to disable these:
- WifiEvent::StationStart
- WifiEvent::StationStop
- WifiEvent::StationConnected
- WifiEvent::StationDisconnected
- WifiEvent::AccessPointStart
- WifiEvent::AccessPointStop
- WifiEvent::AccessPointStationConnected
- WifiEvent::AccessPointStationDisconnected
- WifiEvent::ScanDone
crate::wifi::new always enables these events, even if they were disabled beforehand.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.