pub struct EventSubscriber<'a> { /* private fields */ }Available on crate feature
unstable only.Expand description
Event subscriber.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<'a> EventSubscriber<'a>
impl<'a> EventSubscriber<'a>
Sourcepub async fn next_event(&mut self) -> MessageResult
pub async fn next_event(&mut self) -> MessageResult
Wait for a published event
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub async fn next_event_pure(&mut self) -> EventInfo
pub async fn next_event_pure(&mut self) -> EventInfo
Wait for a published event (ignoring lag results)
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.